@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/delete.c,v 1.11 2000/07/13 18:26:06 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/delete.c,v 1.12 2001/06/15 16:36:36 werner Exp $
  *
  * Loeschen von Dateien / Verzeichnissen
  *
@@ -47,7 +47,7 @@ int DeleteFile(FileEntry *fe_ptr)
         (void) sprintf( message, 
 		        "Can't delete file*\"%s\"*%s", 
 		        filepath, 
-		        sys_errlist[errno] 
+		        strerror(errno) 
    		      );
         MESSAGE( message );
         ESCAPE;
@@ -60,7 +60,7 @@ int DeleteFile(FileEntry *fe_ptr)
     (void) sprintf( message, 
 		    "Can't delete file*\"%s\"*%s", 
 		    filepath, 
-		    sys_errlist[errno] 
+		    strerror(errno) 
 		  );
     MESSAGE( message );
     ESCAPE;
