@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/dirwin.c,v 1.24 2004/11/13 21:08:05 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/dirwin.c,v 1.25 2010/02/28 13:11:53 werner Exp $
  *
  * Funktionen zur Handhabung des DIR-Windows
  *
@@ -822,7 +822,7 @@ int HandleDirWindow(DirEntry *start_dir_entry)
   BOOL need_dsp_help;
   char new_name[PATH_LENGTH + 1];
   char new_login_path[PATH_LENGTH + 1];
-  char *home;
+  char *home, *p;
 
   unput_char = 0;
   de_ptr = NULL;
@@ -1126,6 +1126,36 @@ int HandleDirWindow(DirEntry *start_dir_entry)
       case 'L' & 0x1F:
 		     clearok( stdscr, TRUE );
 		     break;
+
+      case 'P':    /* press 'p' or 'P' to log parent of current root */
+      case 'p':
+
+                MoveHome(&dir_entry);
+          	(void) GetPath(dir_entry, new_login_path);
+
+          	/*  char *p; defined before this current switch */
+          	if((p = strrchr(new_login_path, FILE_SEPARATOR_CHAR)) == NULL)
+              	  break;
+
+          	/*  p is now pointing to rightmost file separator */
+          	/*  in new_login_path, just truncate this path */
+
+          	*p='\0';
+
+          	/*  rightmost slash was first and only character? */
+          	if(!strlen(new_login_path))
+          	{
+              	  new_login_path[0]=FILE_SEPARATOR_CHAR;
+              	  new_login_path[1]='\0';
+          	}
+
+          	/* following needed to ignore old tree in memory */
+          	*disk_statistic.login_path = '\0';
+
+          	(void) LoginDisk(new_login_path);
+          	need_dsp_help = TRUE;
+          	return ch; 
+
       default :      beep();
 		     break;
     } /* switch */
