@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/error.c,v 1.11 2001/04/16 13:34:26 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/error.c,v 1.12 2003/06/06 19:47:26 werner Exp $
  *
  * Ausgabe von Fehlermeldungen
  *
@@ -155,7 +155,7 @@ static void DisplayErrorMessage(char *msg)
     }
     else
     {
-      if( j < (sizeof( buffer) - 1) ) buffer[j++] = msg[i];
+      if( j < (int)((sizeof( buffer) - 1)) ) buffer[j++] = msg[i];
     }
   } 
   buffer[j] = '\0';
