@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/execute.c,v 1.11 2003/03/16 13:13:29 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/execute.c,v 1.13 2004/11/13 20:38:40 werner Exp $
  *
  * Ausfuehren von System-Kommandos
  *
@@ -79,7 +79,7 @@ int GetCommandLine(char *command_line)
   ClearHelp();
 
   MvAddStr( LINES - 2, 1, "Command: " );
-  if( InputString( command_line, LINES - 2, 10, COLS - 11, "\r\033" ) == CR )
+  if( InputString( command_line, LINES - 2, 10, 0, COLS - 11, "\r\033" ) == CR )
   {
     move( LINES - 2, 1 ); clrtoeol();
     result = 0;
@@ -92,6 +92,39 @@ int GetCommandLine(char *command_line)
 
     
 
+int GetSearchCommandLine(char *command_line)
+{
+  int  result;
+  int  pos;
+  char *cptr;
+
+  result = -1;
+
+  ClearHelp();
+
+  MvAddStr( LINES - 2, 1, "Search untag command: " );
+  strcpy( command_line, SEARCHCOMMAND );
+
+  cptr = strstr( command_line, "{}" );
+  if(cptr) {
+    pos = (cptr - command_line) - 1;
+    if(pos < 0)
+      pos = 0;
+  } else {
+    pos = 0;
+  }
+  if( InputString( command_line, LINES - 2, 23, pos, COLS - 24, "\r\033" ) == CR )
+  {
+    move( LINES - 2, 1 ); clrtoeol();
+    result = 0;
+  }
+
+  move( LINES - 2, 1 ); clrtoeol();
+
+  return( result );
+}
+
+    
 
 int ExecuteCommand(FileEntry *fe_ptr, WalkingPackage *walking_package)
 {
@@ -125,7 +158,6 @@ int ExecuteCommand(FileEntry *fe_ptr, WalkingPackage *walking_package)
   /* Ignore Result */
   /*---------------*/
 
-  result = 0;
-
   return( result );
 }
+
