@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/filewin.c,v 1.32 2005/10/05 20:17:42 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/filewin.c,v 1.33 2008/07/09 21:41:58 werner Exp $
  *
  * Funktionen zur Handhabung des FILE-Windows
  *
@@ -2995,7 +2995,7 @@ static int DeleteTaggedFiles(int max_disp_files)
 
 	  deleted = TRUE;
 
-  	  if( fe_ptr->dir_entry->global_flag ) 
+  	  if( de_ptr->global_flag ) 
 	    DisplayDiskStatistic();
 	  else              
 	    DisplayDirStatistic( de_ptr );
