@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/freesp.c,v 1.23 2007/04/01 13:33:36 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/freesp.c,v 1.24 2007/06/04 16:58:03 werner Exp $
  *
  * Ermittlung der freien Plattenkapazitaet
  *
@@ -16,10 +16,10 @@
 #ifdef WIN32
 #include <dos.h>
 #else
-#if defined( SVR4 ) || defined( OSF1 ) || defined( sun56 )
+#if defined( SVR4 ) || defined( OSF1 ) || defined( sun56 ) || defined( __NetBSD__ )
 #include <sys/statvfs.h>
 #else
-#if ( defined( ultrix ) || defined( __OpenBSD__ ) || defined(__NetBSD__) || defined ( __FreeBSD__ ) || defined (__APPLE__) )
+#if ( defined( ultrix ) || defined( __OpenBSD__ ) || defined ( __FreeBSD__ ) || defined (__APPLE__) )
 #include <sys/param.h>
 #include <sys/mount.h>
 #else
@@ -54,7 +54,7 @@ int GetDiskParameter( char *path,
 #ifdef WIN32
   struct _diskfree_t diskspace;
 #else
-#if defined( SVR4 ) || defined( OSF1 )
+#if defined( SVR4 ) || defined( OSF1 ) || defined( __NetBSD__ )
   struct statvfs statfs_struct;
 #else
 #ifdef ultrix
