@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/group.c,v 1.11 2004/11/13 20:38:40 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/group.c,v 1.13 2007/04/01 13:33:36 werner Exp $
  *
  * Handhabung von Gruppen-Nummern / Namen
  *
@@ -23,7 +23,7 @@ typedef struct
 
 
 extern struct group *getgrent(void);
-#if !defined( __FreeBSD__ ) && !defined( OSF1 ) && !defined( __APPLE__ )
+#if !defined(__OpenBSD__) && !defined(__NetBSD__) && !defined( __FreeBSD__ ) && !defined( OSF1 ) && !defined( __APPLE__ )
 extern void         setgrent(void);
 #endif
 
