@@ -12,6 +12,86 @@
  ***************************************************************************/
 
 
+char *StrLeft(const char *str, size_t count)
+{
+#ifdef WITH_UTF8
+  mbstate_t state;
+#endif
+  char *rez, *p, *tmp;
+  size_t len, i;
+
+  if (count == 0) return(Strdup(""));
+  len = StrVisualLength(str);
+  if (count >= len) return(Strdup(str));
+  
+  len = 0;
+
+  tmp = Strdup(str);
+  p = tmp; 
+  for (i = 0; i < count; i++) {
+#ifdef WITH_UTF8
+    len += mbrlen(p, 4, &state);
+#else
+    len++;
+#endif
+    p = tmp + len;
+  }
+  free(tmp);
+  
+  rez = Strndup(str, len);
+  rez[len] = '\0';
+  return(rez);
+}
+
+char *StrRight(const char *str, size_t count)
+{
+#ifdef WITH_UTF8
+  mbstate_t state;
+#endif
+  char *rez, *p, *tmp;
+  size_t byte_len, char_len, tmp_len, i;
+
+  if (count == 0) return(Strdup(""));
+
+  byte_len = strlen(str);
+  char_len = StrVisualLength(str);
+  
+  if (count > char_len) count = char_len;
+  
+  tmp = Strdup(str);
+  p = tmp;
+  i = 0;
+  rez = NULL;
+  while ( (p - tmp) < byte_len ) {
+    if (i == (char_len - count) ) {
+      rez = Strdup(p);
+    }
+#ifdef WITH_UTF8    
+    tmp_len = mbrlen(p, 4, &state);
+#else
+    tmp_len = 1;
+#endif
+    p += tmp_len;
+    i++;
+  }
+
+  free(tmp);
+  return(rez);
+}
+
+int StrVisualLength(const char *str)
+{
+#ifdef WITH_UTF8
+  mbstate_t state;
+  
+  memset(&state, '\0', sizeof(state));
+  return(mbsrtowcs(NULL, &str, strlen(str), &state));
+#else
+  return(strlen(str));
+#endif
+}
+
+
 int InputString(char *s, int y, int x, int cursor_pos, int length, char *term)
                                /* Ein- und Ausgabestring              */
                                /* Position auf Bildschirm             */
@@ -22,11 +102,14 @@ int InputString(char *s, int y, int x, int cursor_pos, int length, char *term)
   int c1;                      /* Gelesenes Zeichen                   */
   int i;                       /* Laufvariable                        */
   char *pp;
-  BOOL key_pressed = FALSE;
+  BOOL len_flag = FALSE;
   char path[PATH_LENGTH + 1];
-
+  char buf[2], sbuf[20], *ls, *rs;
   static BOOL insert_flag = TRUE;
 
+  buf[1] = '\0';
+  strcpy(sbuf, "");
+
   /* Feld gefuellt ausgeben */
   /*------------------------*/
   print_time = FALSE;
@@ -37,109 +120,50 @@ int InputString(char *s, int y, int x, int cursor_pos, int length, char *term)
   for(i=strlen(s); i < length; i++)
     addch( '_' );
 
-
   p = cursor_pos;
+  
+  MvAddStr( y, x, s );
 
-  do  /* until termkey pressed */
-  {
-    wmove( stdscr, y, x+p );
-
-    RefreshWindow( stdscr );
-    doupdate();
-
-    c1 = Getch();
-
-    if( c1 >= ' ' && c1 < 0xff && c1 != 127 ) 
-    {
-      /* Darstellbares Zeichen */
-      /*-----------------------*/
-
-      if( key_pressed == FALSE && cursor_pos == 0 )
-      {
-	s[0] = '\0';
-        
-	move( y, x );
-        for(i=0; i < length; i++)
-          addch( '_' );
-	move( y, x );
-      }
-
-      if( p < length )
-      {
-        /* Platz zum einfuegen vorhanden */
-        /*-------------------------------*/
-
-        if( insert_flag )
+  nodelay( stdscr, TRUE );
+  do {
+    c1 = wgetch(stdscr);
+    
+    if ( c1 != ERR ) {
+    
+      if( c1 >= ' ' && c1 < 0xff && c1 != 127 ) {
+        if ( len_flag == TRUE) beep();
+        else {
+          buf[0] = (char)c1;
+	  strcat(sbuf, buf);
+	}
+      } else {
+        // Control symbols
+        switch( c1 )
         {
-          /* Restliche Zeichen eine Position vorruecken */
-          /*--------------------------------------------*/
-
-          if( strlen( s ) == length ) s[length-1] = '\0';
-          for(i=strlen(s); i >= p; i-- )
-            s[i+1] = s[i];
-        }
-        else
-        {
-          /* Simples ueberschreiben */
-          /*------------------------*/
-
-          if( s[p] == '\0' )
-            s[p+1] = '\0';
-        }
-
-        s[p] = (char) c1;
-
-        addstr( &s[p] );
-        p++;
-      }
-      else
-      {
-        /* Zeile voll */
-        /*------------*/
-
-        beep();
-      }
-    }
-    else
-    {
-      /* Steuerzeichen */
-      /*---------------*/
-
-      switch( c1 )
-      {
-        case 'C' & 0x1f     : c1 = -1; 
+        case 'C' & 0x1f     : c1 = 27; 
 			      break;
-        case -1             : break;
 
         case KEY_LEFT       : if( p > 0 )
                                 p--;
                               else
                                 beep();
                               break;
-/*        case KEY_LEFT & 0x1f: if( p > 2 )
-                                p-=3;
-                              else
-                                beep();
-                              break;*/
-        case KEY_RIGHT      : if( p < (int) strlen( s ) )
+        case KEY_RIGHT      : if( p < StrVisualLength(s) )
                                 p++;
                               else
                                 beep();
                               break;
-/*        case KEY_RIGHT & 0x1f: if( p < (int) strlen( s ) - 3 )
-                                p += 3;
-                              else
-                                beep();
-                              break;*/
 	case KEY_UP         : 
-                             if(( pp = GetHistory()) == NULL) {
-			       break;
-			     }
+	                      nodelay(stdscr, FALSE);
+			      pp = GetHistory();
+			      nodelay(stdscr, TRUE);
+                             if (pp == NULL) break;
                              if(*pp)
                              {
-                               strncpy(s, pp, length);
-			       s[length] = '\0';
-			       p = strlen(s);
+			       ls = StrLeft(pp, length);
+			       strcpy(s, ls);
+			       free(ls);
+			       p = StrVisualLength(s);
                                MvAddStr( y, x, s );
                                for(i=p; i < length; i++)
                                  addch( '_' );
@@ -150,40 +174,41 @@ int InputString(char *s, int y, int x, int cursor_pos, int length, char *term)
 
         case KEY_HOME       : p = 0;
                               break;
-        case KEY_END        : p = strlen( s );
+        case KEY_END        : p = StrVisualLength( s );
                               break;
-        case KEY_DC         : if( p < (int) strlen( s ) )
+        case KEY_DC         : if( p < StrVisualLength(s) )
                               {
-                                (void) strcpy( s+p, s+p+1 );
-                                printw( "%s_", s+p );
+			        ls = StrLeft(s, p);
+				rs = StrRight(s, StrVisualLength(s) - p - 1);
+				strcpy(s, ls);
+				strcat(s, rs);
+				free(ls);
+				free(rs);
+				MvAddStr( y, x, s );
+                                addch( '_' );
                               }
                               break;
 	case 0x08           :
         case 0x7F           :
         case KEY_BACKSPACE  : if( p > 0 )
                               {
-                                (void) strcpy( s+p-1, s+p );
-                                printw( "\b%s_", s+p-1 );
+			        ls = StrLeft(s, p - 1);
+				rs = StrRight(s, StrVisualLength(s) - p);
+				strcpy(s, ls);
+				strcat(s, rs);
+				free(ls);
+				free(rs);
+				MvAddStr( y, x, s );
+                                addch( '_' );
                                 p--;
                               }
                               else
                                 beep();
                               break;
-/*	case 0x08 & 0x1f          :
-        case 0x7F & 0x1f          :
-        case KEY_BACKSPACE & 0x1f : if( p > 1 )
-                              {
-			        beep(); 
-                                (void) strcpy( s+p-1, s+p );
-                                printw( "\b%s_", s+p-1 );
-                                p -= 1;
-                              }
-                              else
-                                beep();
-                              break;*/
-        case KEY_DL         : for(i=0; i < (int) strlen(s) - p; i++)
-			        addch( '_' );
-                              s[p] = '\0';
+        case KEY_DL         : for(i=0; i < StrVisualLength(s) - p; i++) addch( '_' );
+			      ls = StrLeft(s, p);
+			      strcpy(s, ls);
+			      free(ls);
                               break;
 	case KEY_EIC        :
         case KEY_IC         : insert_flag ^= TRUE; 
@@ -193,13 +218,13 @@ int InputString(char *s, int y, int x, int cursor_pos, int length, char *term)
 			     }
                              if(*pp)
                              {
-                               strncpy(s, pp, length);
-			       s[length] = '\0';
+			       ls = StrLeft(pp, length);
+			       strcpy(s, ls);
+			       free(ls);
+			       p = StrVisualLength(s);
 			       free(pp);
-			       p = strlen(s);
                                MvAddStr( y, x, s );
-                               for(i=p; i < length; i++)
-                                 addch( '_' );
+                               for(i=p; i < length; i++) addch( '_' );
                                RefreshWindow( stdscr );
                                doupdate();
                              }
@@ -216,25 +241,66 @@ int InputString(char *s, int y, int x, int cursor_pos, int length, char *term)
 			      }
                               if(*path)
                               {
-                                strncpy(s, path, length);
-			        s[length] = '\0';
-			        p = strlen(s);
+			        ls = StrLeft(path, length);
+				strcpy(s, ls);
+				free(ls);
+			        p = StrVisualLength(s);
                                 MvAddStr( y, x, s );
-                                for(i=p; i < length; i++)
-                                  addch( '_' );
+                                for(i=p; i < length; i++) addch( '_' );
                                 RefreshWindow( stdscr );
                                 doupdate();
                               }
                               break;
 
         default             : if( c1 == LF ) c1 = CR;
-                              if( !strrchr( term, c1 ) )
-                                beep();
                               break;
+        } // switch
+      } // else control symbols
+    } else {
+     
+      if (strlen(sbuf) > 0) {
+       if ( insert_flag ) {
+  	    // append symbol
+	    if ( p >= StrVisualLength(s)) strcat(s, sbuf);
+	    else {
+	      // insert symbol at cursor position
+	      if ( p > 0 ) ls = StrLeft(s, p);
+	      else ls = Strdup("");
+	      rs = StrRight(s, StrVisualLength(s) - p);
+	      strcpy(s, ls);
+	      strcat(s, sbuf);
+	      strcat(s, rs);
+	      free(ls);
+	      free(rs);
+	    }
+          } else {
+            // owerwrite symbol at cursor position
+	    if ( p > StrVisualLength(s) - 1) strcat(s, sbuf);
+	    else {
+  	      if (p > 0) ls = StrLeft(s, p);
+	      else ls = Strdup("");
+	      rs = StrRight(s, StrVisualLength(s) - p - 1);
+	      strcpy(s, ls);
+	      strcat(s, sbuf);
+	      strcat(s, rs);
+	      free(ls);
+	      free(rs);
+	    }
+	  }
+
+	strcpy(sbuf, "");
+	p++;
       }
+
+      if (StrVisualLength(s) >= length) len_flag = TRUE;
+      else len_flag = FALSE;
+
+      MvAddStr( y, x, s );
+      wmove(stdscr, y, x + p);
     }
-    key_pressed = TRUE;
-  } while( c1 != -1 && !strrchr( term, c1 ) );
+  } while( c1 !=  27 && c1 != CR );
+
+  nodelay( stdscr, FALSE );
 
   p = strlen( s );
   move( y, x + p );
@@ -298,7 +364,7 @@ int InputChoise(char *msg, char *term)
 int GetTapeDeviceName( void )
 {
   int  result;
-  char path[PATH_LENGTH+1];
+  char path[PATH_LENGTH * 2 +1];
 
   result = -1;
 
