@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/match.c,v 1.16 2004/11/13 20:38:40 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/match.c,v 1.18 2007/04/01 13:33:36 werner Exp $
  *
  * Behandlung reg. Ausdruecke fuer Dateinamen
  *
@@ -9,7 +9,7 @@
 
 #include "ytree.h"
 
-#if defined( bsd ) || defined( sun ) || defined( linux ) || defined( __NeXT__ ) || defined( OSF1 ) || defined( __FreeBSD__ ) || defined( __GNU__ )
+#if defined( sun ) || defined( linux ) || defined( __NeXT__ ) || defined( OSF1 ) ||  defined( __OpenBSD__ ) || defined(__NetBSD__) || defined( __FreeBSD__ ) || defined( __GNU__ )
 #define HAS_REGEX
 #endif
 
