@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/mkdir.c,v 1.16 2004/03/21 14:13:11 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/mkdir.c,v 1.17 2005/01/22 16:32:29 werner Exp $
  *
  * Erstellen von Verzeichnissen
  *
@@ -14,7 +14,7 @@
 
 int MakeDirectory(DirEntry *father_dir_entry)
 {
-  char dir_name[PATH_LENGTH+1];
+  char dir_name[PATH_LENGTH * 2 +1];
   int result = -1;
 
   if( mode != DISK_MODE && mode != USER_MODE )
