@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/rename.c,v 1.12 2001/06/15 16:36:36 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/rename.c,v 1.13 2004/03/21 14:13:11 werner Exp $
  *
  * Umbenennen von Dateien/Verzeichnissen
  *
@@ -258,7 +258,7 @@ int GetRenameParameter(char *old_name, char *new_name)
   (void) strcpy( new_name, (old_name) ? old_name : "*" );
 
 
-  if( InputString(new_name, LINES - 2, l, COLS - l - 1, "\r\033" ) != CR)
+  if( InputString(new_name, LINES - 2, l, 0, COLS - l - 1, "\r\033" ) != CR)
     return( -1 );
 
   return( 0 );
