@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/util.c,v 1.33 2005/09/07 18:50:33 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/util.c,v 1.34 2006/11/13 16:49:16 werner Exp $
  *
  * Diverse Hilfsfunktionen
  *
@@ -305,7 +305,7 @@ void PrintSpecialString(WINDOW *win, int y, int x, char *str, int color)
 
   for( ; *str; str++ )
   {
-    if ( (!iscntrl(*str)) || (!isspace(*str)) || (*str=' ') ) 
+    if ( (!iscntrl(*str)) || (!isspace(*str)) || (*str==' ') ) 
     switch( *str )
     {
       case '1': ch = ACS_ULCORNER; break;
@@ -323,6 +323,7 @@ void PrintSpecialString(WINDOW *win, int y, int x, char *str, int color)
     }
     else
             ch = ACS_BLOCK;
+
 #ifdef COLOR_SUPPORT
     wattrset( win, COLOR_PAIR(color) | A_BOLD );
 #endif /* COLOR_SUPPORT */
