@@ -1,6 +1,6 @@
 /***************************************************************************
  *
- * $Header: /usr/local/cvsroot/utils/ytree/ytree.h,v 1.42 2007/06/04 16:58:03 werner Exp $
+ * $Header: /usr/local/cvsroot/utils/ytree/ytree.h,v 1.44 2008/07/26 14:29:30 werner Exp $
  *
  * Header-Datei fuer YTREE
  *
@@ -15,7 +15,7 @@
 #include <ctype.h>
 #include <math.h>
 
-#if defined(__OpenBSD__) || defined(__NetBSD__) || defined(__FreeBSD__) || defined(__NetBSD__)
+#if defined(__OpenBSD__) || defined(__NetBSD__) || defined(__FreeBSD__) || defined(__NetBSD__) || defined(__APPLE__)
 #include <locale.h>
 #endif
 
@@ -958,6 +958,7 @@ extern char *GetRealFileNamePath(FileEntry *file_entry, char *buffer);
 extern int  SystemCall(char *command_line);
 extern int  QuerySystemCall(char *command_line);
 extern int  SilentSystemCall(char *command_line);
+extern int  SilentSystemCallEx(char *command_line, BOOL enable_clock);
 extern int  View(DirEntry * dir_entry, char *file_path);
 extern int  ViewHex(char *file_path);
 extern int  InternalView(char *file_path);
